document.addEventListener('DOMContentLoaded', () => {
  // Smooth scrolling for anchor links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      document.querySelector(this.getAttribute('href')).scrollIntoView({
        behavior: 'smooth'
      });
    });
  });

  // Mobile menu toggle
  const createMobileMenu = () => {
    const nav = document.querySelector('.main-nav');
    const burger = document.createElement('div');
    burger.className = 'burger';
    burger.innerHTML = '☰';
    burger.style.display = 'none';
    
    if (window.innerWidth <= 768) {
      burger.style.display = 'block';
    }
    
    nav.prepend(burger);
    
    burger.addEventListener('click', () => {
      const navLinks = document.querySelector('.nav-links');
      navLinks.style.display = navLinks.style.display === 'flex' ? 'none' : 'flex';
    });
  };

  createMobileMenu();
  
  // Lazy loading for images
  const images = document.querySelectorAll('img');
  const imageOptions = {
    threshold: 0,
    rootMargin: '0px 0px 50px 0px'
  };
  
  const imageObserver = new IntersectionObserver((entries, observer) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        const img = entry.target;
        img.src = img.src;
        observer.unobserve(img);
      }
    });
  }, imageOptions);
  
  images.forEach(img => imageObserver.observe(img));
});